@@ -3,4 +3,4 @@
 // SPDX-License-Identifier: MIT
 
 pub mod v1;
-pub mod v2_rc;
+pub mod v2_beta;
