@@ -69,7 +69,7 @@ pub fn get<R: Runtime>(
 }
 
 fn get_response<R: Runtime>(
-  request: Request<Vec<u8>>,
+  #[allow(unused_mut)] mut request: Request<Vec<u8>>,
   #[allow(unused_variables)] manager: &AppManager<R>,
   window_origin: &str,
   web_resource_request_handler: Option<&WebResourceRequestHandler>,
@@ -118,9 +118,11 @@ fn get_response<R: Runtime>(
       .build()
       .unwrap()
       .request(request.method().clone(), &url);
+    proxy_builder = proxy_builder.body(std::mem::take(request.body_mut()));
     for (name, value) in request.headers() {
       proxy_builder = proxy_builder.header(name, value);
     }
+    proxy_builder = proxy_builder.body(request.body().clone());
     match crate::async_runtime::safe_block_on(proxy_builder.send()) {
       Ok(r) => {
         let mut response_cache_ = response_cache.lock().unwrap();
