@@ -2325,6 +2325,14 @@ interface WindowOptions {
    * The style of the macOS title bar.
    */
   titleBarStyle?: TitleBarStyle
+  /**
+   * The position of the window controls on macOS.
+   *
+   * Requires `titleBarStyle: 'overlay'` and `decorations: true`.
+   *
+   * @since 2.4.0
+   */
+  trafficLightPosition?: LogicalPosition
   /**
    * If `true`, sets the window title to be hidden on macOS.
    */
